==> tmw_0.0.23.orig.tar.gz: tmw-0.0.23/src/gui/debugwindow.h <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: debugwindow.h 3290 2007-05-04 13:09:25Z crush_tmw $
 */

#ifndef _TMW_DEBUGWINDOW_H
#define _TMW_DEBUGWINDOW_H

#include <iosfwd>

#include <guichan/actionlistener.hpp>

#include "window.h"

#include "../guichanfwd.h"

/**
 * The chat window.
 *
 * \ingroup Interface
 */
class DebugWindow : public Window, public gcn::ActionListener
{
    public:
        /**
         * Constructor.
         */
        DebugWindow();

        /**
         * Logic (updates components' size and infos)
         */
        void logic();

        /**
         * Performs action.
         */
        void action(const gcn::ActionEvent &event);

    private:
        gcn::Label *mMusicFileLabel, *mMapFileLabel;
        gcn::Label *mTileMouseLabel, *mFPSLabel;
        gcn::Label *mParticleCountLabel;
};

#endif

==> tmw_0.0.24.1.orig.tar.gz: tmw-0.0.24.1/src/gui/debugwindow.h <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: debugwindow.h 4046 2008-04-07 15:41:22Z b_lindeijer $
 */

#ifndef _TMW_DEBUGWINDOW_H
#define _TMW_DEBUGWINDOW_H

#include <iosfwd>

#include <guichan/actionlistener.hpp>

#include "window.h"

#include "../guichanfwd.h"

/**
 * The debug window.
 *
 * \ingroup Interface
 */
class DebugWindow : public Window
{
    public:
        /**
         * Constructor.
         */
        DebugWindow();

        /**
         * Logic (updates components' size and infos)
         */
        void logic();

    private:
        gcn::Label *mMusicFileLabel, *mMapFileLabel;
        gcn::Label *mTileMouseLabel, *mFPSLabel;
        gcn::Label *mParticleCountLabel;
};

#endif
